Module block

Module block 

Traits used to define functionality of block ciphers and modes of operation.

About block ciphers

Block ciphers are keyed, deterministic permutations of a fixed-sized input “block” providing a reversible transformation to/from an encrypted output. They are one of the fundamental structural components of symmetric cryptography.

Traits

BlockCipherDecBackend
Trait implemented by block cipher decryption backends.
BlockCipherDecClosure
Trait for BlockCipherDecBackend users.
BlockCipherDecrypt
Decrypt-only functionality for block ciphers.
BlockCipherEncBackend
Trait implemented by block cipher mode encryption backends.
BlockCipherEncClosure
Trait for BlockCipherEncBackend users.
BlockCipherEncrypt
Encrypt-only functionality for block ciphers.
BlockModeDecBackend
Trait implemented by block cipher mode decryption backends.
BlockModeDecClosure
Trait for BlockModeDecBackend users.
BlockModeDecrypt
Decrypt-only functionality for block ciphers and modes with mutable access to self.
BlockModeEncBackend
Trait implemented by block cipher mode encryption backends.
BlockModeEncClosure
Trait for BlockModeEncBackend users.
BlockModeEncrypt
Encrypt-only functionality for block ciphers and modes with mutable access to self.