Traits used to define functionality of block ciphers and modes of operation.
About block ciphers
Block ciphers are keyed, deterministic permutations of a fixed-sized input “block” providing a reversible transformation to/from an encrypted output. They are one of the fundamental structural components of symmetric cryptography.
Traits
- Block
Cipher DecBackend - Trait implemented by block cipher decryption backends.
- Block
Cipher DecClosure - Trait for
BlockCipherDecBackendusers. - Block
Cipher Decrypt - Decrypt-only functionality for block ciphers.
- Block
Cipher EncBackend - Trait implemented by block cipher mode encryption backends.
- Block
Cipher EncClosure - Trait for
BlockCipherEncBackendusers. - Block
Cipher Encrypt - Encrypt-only functionality for block ciphers.
- Block
Mode DecBackend - Trait implemented by block cipher mode decryption backends.
- Block
Mode DecClosure - Trait for
BlockModeDecBackendusers. - Block
Mode Decrypt - Decrypt-only functionality for block ciphers and modes with mutable access to
self. - Block
Mode EncBackend - Trait implemented by block cipher mode encryption backends.
- Block
Mode EncClosure - Trait for
BlockModeEncBackendusers. - Block
Mode Encrypt - Encrypt-only functionality for block ciphers and modes with mutable access to
self.