Module stream

Module stream 

Traits which define functionality of stream ciphers.

See the RustCrypto/stream-ciphers repository for ciphers implementation.

Structs

OverflowError
The error type returned when a cipher position can not be represented by the requested type.
StreamCipherCoreWrapperstream-wrapper
Buffering wrapper around a StreamCipherCore implementation.
StreamCipherError
This error is returned by the StreamCipher trait methods.

Traits

SeekNum
Trait implemented for numeric types which can be used with the StreamCipherSeek trait.
StreamCipher
Stream cipher trait.
StreamCipherBackend
Trait implemented by stream cipher backends.
StreamCipherClosure
Trait for StreamCipherBackend users.
StreamCipherCore
Block-level synchronous stream ciphers.
StreamCipherCounter
Counter type usable with StreamCipherCore.
StreamCipherSeek
Trait for seekable stream ciphers.
StreamCipherSeekCore
Block-level seeking trait for stream ciphers.