Traits which define functionality of stream ciphers.
See the RustCrypto/stream-ciphers repository for ciphers implementation.
Structs
- Overflow
Error - The error type returned when a cipher position can not be represented by the requested type.
- Stream
Cipher Core Wrapper stream-wrapper - Buffering wrapper around a
StreamCipherCoreimplementation. - Stream
Cipher Error - This error is returned by the
StreamCiphertrait methods.
Traits
- SeekNum
- Trait implemented for numeric types which can be used with the
StreamCipherSeektrait. - Stream
Cipher - Stream cipher trait.
- Stream
Cipher Backend - Trait implemented by stream cipher backends.
- Stream
Cipher Closure - Trait for
StreamCipherBackendusers. - Stream
Cipher Core - Block-level synchronous stream ciphers.
- Stream
Cipher Counter - Counter type usable with
StreamCipherCore. - Stream
Cipher Seek - Trait for seekable stream ciphers.
- Stream
Cipher Seek Core - Block-level seeking trait for stream ciphers.