Traits used to define functionality of tweakable block ciphers.
Structs
- Zero
Tweak - Wrapper around tweakable block cipher which implements the common block cipher traits using zero tweak.
Traits
- Tweak
Block Cipher DecBackend - Trait implemented by block cipher mode decryption backends.
- Tweak
Block Cipher DecClosure - Trait for
TweakBlockCipherDecBackendusers. - Tweak
Block Cipher Decrypt - Decrypt-only functionality for tweakable block ciphers.
- Tweak
Block Cipher EncBackend - Trait implemented by block cipher mode encryption backends.
- Tweak
Block Cipher EncClosure - Trait for
TweakBlockCipherEncBackendusers. - Tweak
Block Cipher Encrypt - Encrypt-only functionality for tweakable block ciphers.
- Tweak
Size User - Trait which contains tweak size used by the tweak cipher traits.
Type Aliases
- Tweak
- Tweak used by a
TweakSizeUserimplementor.